# Save your variable as Rstudio!!
Tools for Data science
## dumps()
Dump your variable
## loads()
Load your variable
## type_list
The type of variable that needs to be saved
## drop_list
Variables that you don't want to save(for jupyter)